@@ -5,7 +5,7 @@
 
 import glob
 import os
-from typing import Dict, Tuple
+from typing import Dict, Tuple, List, Optional
 
 from graphql import GraphQLSchema
 from graphql.language.parser import parse
@@ -15,7 +15,7 @@ from .constant import ENUM_DIRNAME, INPUT_DIRNAME
 from .query_parser import InvalidQueryError, QueryParser
 from .renderer_dataclasses import DataclassesRenderer
 from .utils_codegen import CodeChunk, camel_case_to_lower_case
-from .utils_schema import compile_schema_library, get_query_details, QueryType
+from .utils_schema import get_query_details, QueryType
 
 
 def assert_rendered_file(file_name: str, file_content: str, rendered: str) -> None:
@@ -65,6 +65,24 @@ def make_python_package(pkg_name: str) -> None:
     add_init_file(pkg_name)
 
 
+def root_no_ext(filename):
+    root, _s = os.path.splitext(filename)
+    return root
+
+
+def get_import_path(filename, target_dirname):
+    importpath = (
+        root_no_ext(os.path.relpath(filename, target_dirname))
+        .replace("../../../", "....")
+        .replace("../../", "...")
+        .replace("../", "..")
+        .replace("/", ".")
+    )
+    if not importpath.startswith("."):
+        return "." + importpath
+    return importpath
+
+
 def process_file(
     filename: str,
     query: str,
@@ -74,6 +92,7 @@ def process_file(
     fragment_library: Dict[str, Tuple[str, str]],
     enum_dir_path: str,
     input_dir_path: str,
+    config_path: Optional[str],
     verify: bool = False,
 ) -> None:
     full_fragments = "".join(
@@ -84,46 +103,50 @@ def process_file(
         ]
     )
 
-    def root_no_ext(filename):
-        root, _s = os.path.splitext(filename)
-        return root
-
     target_filename = "".join([root_no_ext(filename), ".py"])
     target_dirname = os.path.dirname(filename)
 
-    def get_import_path(filename, target_dirname):
-        importpath = (
-            root_no_ext(os.path.relpath(filename, target_dirname))
-            .replace("../", "..")
-            .replace("/", ".")
-        )
-        if not importpath.startswith("."):
-            return "." + importpath
-        return importpath
-
     try:
         parsed = parser.parse(query, full_fragments)
         fragment_name_to_importpath = {
             name: get_import_path(details[0], target_dirname)
             for name, details in fragment_library.items()
         }
-        rendered = renderer.render(parsed, fragment_name_to_importpath)
-        verify_or_write_rendered(target_filename, rendered, verify)
 
+        enum_name_to_importpath = {}
         enums = renderer.render_enums(parsed)
         for enum_name, code in enums.items():
             target_enum_filename = os.path.join(
                 enum_dir_path, "".join([camel_case_to_lower_case(enum_name), ".py"])
             )
             verify_or_write_rendered(target_enum_filename, code, verify)
+            enum_name_to_importpath[enum_name] = get_import_path(
+                target_enum_filename, target_dirname
+            )
 
-        input_objects = renderer.render_input_objects(parsed)
+        input_name_to_importpath = {}
+        input_objects = renderer.render_input_objects(
+            parsed,
+            get_import_path(config_path, input_dir_path) if config_path else None,
+        )
         for input_object_name, code in input_objects.items():
             target_input_object_filename = os.path.join(
                 input_dir_path,
                 "".join([camel_case_to_lower_case(input_object_name), ".py"]),
             )
             verify_or_write_rendered(target_input_object_filename, code, verify)
+            input_name_to_importpath[input_object_name] = get_import_path(
+                target_input_object_filename, target_dirname
+            )
+
+        rendered = renderer.render(
+            parsed,
+            fragment_name_to_importpath,
+            enum_name_to_importpath,
+            input_name_to_importpath,
+            get_import_path(config_path, target_dirname) if config_path else None,
+        )
+        verify_or_write_rendered(target_filename, rendered, verify)
     except (InvalidQueryError, AssertionError):
         if verify:
             print(f"Failed to verify graphql file {filename}")
@@ -134,16 +157,17 @@ def process_file(
 
 
 def run(
-    schema_library: str,
+    schema: GraphQLSchema,
     graphql_library: str,
     verify: bool = False,
     allow_deprecated: bool = False,
+    config_path: str = None,
 ) -> None:
-    schema = compile_schema_library(schema_library)
     filenames = glob.glob(os.path.join(graphql_library, "**/*.graphql"), recursive=True)
 
     query_parser = QueryParser(schema)
-    query_renderer = DataclassesRenderer(schema)
+
+    query_renderer = DataclassesRenderer(schema, config_path)
 
     enum_dir_path = os.path.join(graphql_library, ENUM_DIRNAME)
     input_dir_path = os.path.join(graphql_library, INPUT_DIRNAME)
@@ -157,7 +181,7 @@ def run(
         make_python_package(enum_dir_path)
         make_python_package(input_dir_path)
 
-    operation_library: Dict[str, Tuple[str, str]] = {}
+    operation_library: List[Tuple[str, str]] = []
     fragment_library: Dict[str, Tuple[str, str]] = {}
 
     for filename in filenames:
@@ -171,7 +195,7 @@ def run(
             ), f"Graphql file name {filename} uses deprecated fields {usages}"
         query_name, query_type = get_query_details(parsed_query)
         if query_type == QueryType.OPERATION:
-            operation_library[query_name] = (filename, query)
+            operation_library.append((filename, query))
         else:
             fragment_library[query_name] = (filename, query)
         dirname = os.path.dirname(filename)
@@ -189,9 +213,10 @@ def run(
             fragment_library,
             enum_dir_path,
             input_dir_path,
+            config_path,
             verify,
         )
-    for filename, query in operation_library.values():
+    for filename, query in operation_library:
         process_file(
             filename,
             query,
@@ -201,5 +226,6 @@ def run(
             fragment_library,
             enum_dir_path,
             input_dir_path,
+            config_path,
             verify,
         )
