@@ -1,4 +1,8 @@
 #!/usr/bin/env python3
+# Copyright (c) 2004-present Facebook All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 import os
 import re
 
@@ -9,11 +13,6 @@ def camel_case_to_lower_case(string: str) -> str:
     return re.sub(r"(?<!^)(?=[A-Z])", "_", string).lower()
 
 
-def remove_dirname_in_import(dirname: str, rendered: str) -> str:
-    pattern = "".join([r"\.\.", f"{dirname}", r"\."])
-    return re.sub(pattern, ".", rendered)
-
-
 class CodeChunk:
     class Block:
         def __init__(self, codegen: "CodeChunk"):
